/*****************************************************************************
 *                Copyright (C) 2013 Radian Memory Systems 
 *
 * This file is provided under non-disclosure agreement.
 * See the file COPYING for details.
 ******************************************************************************/
#ifndef _RMS200_HW_INFO_H_
#define _RMS200_HW_INFO_H_

#define RMS200_MAGIC 0x43212143

#define RMS_HW_INFO_MAGIC RMS200_MAGIC

typedef struct rms200_hw_info {
    u32 magic;
    u32 dmi_window_size0; /* MB */
    u32 dmi_window_size1; /* MB */
    u32 ddr_size;   	/* MB */
    u32 flash_type;     /* MB */
    u32 flash_chip_size; /* MB */
    u32 num_flash_chips; 
    u32 model_number;
    u8 top_rev_number[8];
    u8 serial_number[8];
    u8 sbl_id[8];	/* Version number of the bootloader */
    u8 firmware_id[8];   /* Mfg. version of software */
    u8 firmware_id2[8];  /* Software version in user slot ??? */
    u8 capacitor_capacity[32]; /* This is a null-terminated string */
    u8 qa_date[32];    /* A null-terminated string, format is same as Linux 'date' command */
    u32 dmi_window_old; /* MB */
    u32 dmi_window_old1; /* MB */
    u8 firmware_id3[8];  /* Software version in user slot ??? */
    u8 firmware_id4[8];  /* Software version in user slot ??? */
} rms200_hw_info_t;

/*
 * At the begining of the eeprom we store the board information followed by 
 * a padding for future additions. 
 * Following are the dialog parametes.
 * At 1k is the Bad block table. 
*/
struct rms200_eeprom_head {

	rms200_hw_info_t  hw_info;
    /*
     * Padding for future use.
     */
    u8 reserved1[256 - sizeof(rms200_hw_info_t)];

	dialog_config_t	  dialog; 

	u8 reserved2[(1024-256) - sizeof(dialog_config_t)];
};

typedef struct rms200_eeprom_head rms200_eeprom_head_t;

#endif 
